==> IDSL.IPA_1.2.tar.gz: IDSL.IPA/man/chromatography_analysis.Rd <==
\name{chromatography_analysis}
\alias{chromatography_analysis}
\title{
Chromatography analysis
}
\description{
This function detect individual chromatographic peaks and measures their peak qualification metrics.
}
\usage{
chromatography_analysis(spec_scan_xic, smoothing_window,
peak_resolving_power, min_nIsoPair, min_peak_height,
min_ratio_IsoPair, max_rpw, min_snr_baseline,
max_R13C_integrated_peak, max_percentage_missing_scans,
mz_target, rt_target = 0, mass_accuracy_xic, spectraList,
RetentionTime, n_spline)
}
\arguments{
  \item{spec_scan_xic}{
a matrix consists of 5 columns. The column contents are the m/z of 12C
isotoplogues, intensity of 12C isotoplogues, scan number (t), m/z of 13C
isotoplogues, and intensity of 13C isotoplogues, respectively.
}
  \item{smoothing_window}{
a number of scans for peak smoothing.
}
  \item{peak_resolving_power}{
a value to represent peak resolving power.
}
  \item{min_nIsoPair}{
a minimum number of nIsoPair for an individual peak.
}
  \item{min_peak_height}{
a minimum peak height for an individual peak.
}
  \item{min_ratio_IsoPair}{
a minimum ratio of nIsoPair per number of available scans within an individual
peak.
}
  \item{max_rpw}{
a maximum allowed value of ratio of peak width at half-height to baseline (RPW)
for an individual peak.
}
  \item{min_snr_baseline}{
a minimum S/N baseline for an individual peak.
}
  \item{max_R13C_integrated_peak}{
a maximum allowed value of average R13C for an individual peak.
}
  \item{max_percentage_missing_scans}{
a maximum allowed value of percentage missing scans on the raw chromatogram for
an individual peak.
}
  \item{mz_target}{
a m/z value to perform chromatography analysis.
}
  \item{rt_target}{
a retention time value for a targeted peak to calculate the ancillary
chromatography parameters. When this parameter set at 0, the ancillary
chromatography parameters are calculated for the entire detected peaks.
}
  \item{mass_accuracy_xic}{
a mass error to perform chromatography analysis.
}
  \item{spectraList}{
a list of mass spectra in each chromatogram scan.
}
  \item{RetentionTime}{
a vector of retention times vs. corresponding scan numbers.
}
  \item{n_spline}{
number of points for further smoothing using a cubic spline smoothing method to
calculate ancillary chromatographical parameters.
}
}
\value{
a data frame consisting of 24 columns representing chromatography and mass
spectrometry parameters. Each row represents an individual seperated
chromatographic peak.
}

==> IDSL.IPA_1.6.tar.gz: IDSL.IPA/man/chromatography_analysis.Rd <==
\name{chromatography_analysis}
\alias{chromatography_analysis}
\title{
Chromatography analysis
}
\description{
This function detect individual chromatographic peaks and measures their peak qualification metrics.
}
\usage{
chromatography_analysis(spec_scan_xic, smoothing_window,
peak_resolving_power, min_nIsoPair, min_peak_height,
min_ratio_IsoPair, max_rpw, min_snr_baseline,
max_R13C_integrated_peak, max_percentage_missing_scans,
mz_target, rt_target = 0, mass_accuracy_xic, spectraList,
RetentionTime, n_spline)
}
\arguments{
  \item{spec_scan_xic}{
a matrix consists of 5 columns. The column contents are the m/z of 12C
isotoplogues, intensity of 12C isotoplogues, scan number (t), m/z of 13C
isotoplogues, and intensity of 13C isotoplogues, respectively.
}
  \item{smoothing_window}{
number of scans for peak smoothing
}
  \item{peak_resolving_power}{
a value to represent peak resolving power
}
  \item{min_nIsoPair}{
minimum number of nIsoPair for an individual peak
}
  \item{min_peak_height}{
minimum peak height for an individual peak
}
  \item{min_ratio_IsoPair}{
minimum ratio of nIsoPair per number of available scans within an individual
peak
}
  \item{max_rpw}{
maximum allowed value of ratio of peak width at half-height to baseline (RPW)
for an individual peak
}
  \item{min_snr_baseline}{
minimum S/N baseline for an individual peak
}
  \item{max_R13C_integrated_peak}{
maximum allowed value of average R13C for an individual peak
}
  \item{max_percentage_missing_scans}{
maximum allowed value of percentage missing scans on the raw chromatogram for
an individual peak.
}
  \item{mz_target}{
m/z value to perform chromatography analysis
}
  \item{rt_target}{
retention time value for a targeted peak to calculate the ancillary
chromatography parameters. When this parameter set at 0, the ancillary
chromatography parameters are calculated for the entire detected peaks.
}
  \item{mass_accuracy_xic}{
mass error to perform chromatography analysis
}
  \item{spectraList}{
a list of mass spectra in each chromatogram scan
}
  \item{RetentionTime}{
a vector of retention times vs. corresponding scan numbers
}
  \item{n_spline}{
number of points for further smoothing using a cubic spline smoothing method to
calculate ancillary chromatographical parameters
}
}
\value{
a data frame consisting of 24 columns representing chromatography and mass
spectrometry parameters. Each row represents an individual seperated
chromatographic peak.
}
